@@ -317,10 +317,6 @@ class ApiAdapter(object):
     def get_list_members(self, list):
         pass
 
-    @abstractmethod
-    def is_list_member(self, user, list):
-        pass
-
     @abstractmethod
     def subscribe_to_list(self, list):
         pass
@@ -329,10 +325,6 @@ class ApiAdapter(object):
     def get_list_subscribers(self, list):
         pass
 
-    @abstractmethod
-    def is_list_subscriber(self, user, list):
-        pass
-
 
 class AsyncApi(ApiAdapter):
     """
@@ -470,14 +462,8 @@ class AsyncApi(ApiAdapter):
     def get_list_members(self, list):
         pass
 
-    def is_list_member(self, user, list):
-        pass
-
     def subscribe_to_list(self, list):
         pass
 
     def get_list_subscribers(self, list):
         pass
-
-    def is_list_subscriber(self, user, list):
-        pass
