@@ -6,7 +6,10 @@ This module contains the curses UI widgets.
 
 import os
 import logging
+import re
 from gettext import gettext as _
+from htmlentitydefs import entitydefs
+
 
 from urwid import (AttrMap, WidgetWrap, Padding, Divider, SolidFill,
                    WidgetDecoration, LineBox, Filler,
@@ -268,7 +271,7 @@ class CursesInterface(WidgetWrap):
                            header=header,
                            footer=footer)
 
-        WidgetWrap.__init__(self, self.frame)
+        super(CursesInterface, self).__init__(self.frame)
 
     def _build_overlay_widget(self,
                               top_w,
@@ -498,15 +501,15 @@ class Banner(WidgetWrap):
             "  | |_| |_| | |  \__ |  __/\__ | ",
             "  \___|\____|_| |____/\___||___/ ",
             "  ······························ ",
-            "{}".format(version),
+            "{0}".format(version),
             "",
             "",
-            _("Press '{}' for help").format(help_key),
-            _("Press '{}' to quit turses").format(quit_key),
+            _("Press '{0}' for help").format(help_key),
+            _("Press '{0}' to quit turses").format(quit_key),
             "",
             "",
             _("Configuration and token files reside under"),
-            _("your $HOME directory ({})").format(home_dir),
+            _("your $HOME directory ({0})").format(home_dir),
             #"",
             "",
             "    ~                                              ",
@@ -519,7 +522,7 @@ class Banner(WidgetWrap):
             "",
             "",
         ]
-        self.__super.__init__(self._create_text())
+        super(Banner, self).__init__(self._create_text())
 
     def _create_text(self):
         """Create the text to display in the welcome buffer."""
@@ -562,7 +565,7 @@ class BaseEditor(WidgetWrap):
         and `BaseEditor` will wrap it in a `urwid.Colums` widget, calling to
         `urwid.WidgetWrap.__init__` with the wrapped widget.
         """
-        caption = _(u'{} (Enter key twice to validate, '
+        caption = _(u'{0} (Enter key twice to validate, '
                     u'Esc or Ctrl-C to cancel) \n>> ').format(prompt)
         if content:
             content += ' '
@@ -579,7 +582,7 @@ class BaseEditor(WidgetWrap):
         composed_widget = Columns(widgets)
 
         widget = AttrMap(LineBox(composed_widget), 'editor')
-        WidgetWrap.__init__(self, widget)
+        super(BaseEditor, self).__init__(widget)
 
     def keypress(self, size, key):
         if key == 'enter' and self.last_key == 'enter':
@@ -614,12 +617,10 @@ class TextEditor(BaseEditor):
                  content,
                  done_signal_handler,
                  cursor_position=None):
-        BaseEditor.__init__(self,
-                            prompt,
-                            content,
-                            done_signal_handler,
-                            cursor_position)
-
+        super(TextEditor, self).__init__(prompt,
+                                         content,
+                                         done_signal_handler,
+                                         cursor_position)
         self._wrap(self.editor)
 
 
@@ -634,11 +635,10 @@ class TweetEditor(BaseEditor):
                  content,
                  done_signal_handler,
                  cursor_position=None):
-        BaseEditor.__init__(self,
-                            prompt,
-                            content,
-                            done_signal_handler,
-                            cursor_position)
+        super(TweetEditor, self).__init__(prompt,
+                                          content,
+                                          done_signal_handler,
+                                          cursor_position)
 
         self.counter = len(self.content)
         self.counter_widget = Text(str(self.counter))
@@ -671,10 +671,9 @@ class DmEditor(TweetEditor):
                  content,
                  done_signal_handler):
         self.recipient = recipient
-        TweetEditor.__init__(self,
-                             prompt='DM to {}'.format(recipient),
-                             content='',
-                             done_signal_handler=done_signal_handler)
+        super(DmEditor, self).__init__(prompt='DM to {0}'.format(recipient),
+                                       content='',
+                                       done_signal_handler=done_signal_handler)
 
     def emit_done_signal(self, content=None):
         emit_signal(self, 'done', self.recipient, content)
@@ -701,7 +700,7 @@ class TabsWidget(WidgetWrap):
             self.visible_indexes = []
         created_text = self._create_text()
         text = created_text if created_text else ''
-        WidgetWrap.__init__(self, Text(text))
+        super(TabsWidget, self).__init__(Text(text))
 
     def _is_valid_index(self, index):
         return index >= 0 and index < len(self.tabs)
@@ -754,7 +753,7 @@ class StatusBar(WidgetWrap):
     ARROW = " => "
 
     def __init__(self, text=''):
-        WidgetWrap.__init__(self, Text(text))
+        super(StatusBar, self).__init__(Text(text))
 
     def message(self, text):
         """Write `text` on the footer."""
@@ -996,7 +995,7 @@ class TimelinesBuffer(ScrollableWidgetWrap):
         self.columns.set_focus_column(index)
 
     # XXX:
-    #  All keypresses are ignored so `turses.core.KeyHandler` can handle
+    #  All keypresses are ignored so `turses.core.InpuHandler` can handle
     #  every keystroke. I tried to filter the input in `urwid`s `MainLoop`
     #  but did not work as expected.
     def keypress(self, size, key):
@@ -1038,7 +1037,8 @@ class StatusWidget(WidgetWrap):
         divider = configuration.styles.get('status_divider', False)
 
         header = AttrMap(Text(header_text), 'header')
-        body = Padding(AttrMap(Text(text), 'body'), left=1, right=1)
+        sanitized_text = [sanitize(t) for t in text] if isinstance(text, list) else sanitize(text)
+        body = Padding(AttrMap(Text(sanitized_text), 'body'), left=1, right=1)
 
         border_attr = 'line'
         if favorite:
@@ -1195,7 +1195,7 @@ class UserInfo(WidgetWrap):
         Receive a ``user`` and its ``last_statuses`` to render the widget.
         """
         whitespace = Divider(' ')
-        widgets = [Text(u"{}".format(user.name)), whitespace]
+        widgets = [Text(u"{0}".format(user.name)), whitespace]
 
         # bio
         if user.description:
@@ -1211,9 +1211,9 @@ class UserInfo(WidgetWrap):
 
         # statistics: following, followers and favorites
         # TODO: tweet count
-        following = Text(_('following:\n{}'.format(user.friends_count)))
-        followers = Text(_('followers:\n{}'.format(user.followers_count)))
-        favorites = Text(_('favorites:\n{}'.format(user.favorites_count)))
+        following = Text(_('following:\n{0}'.format(user.friends_count)))
+        followers = Text(_('followers:\n{0}'.format(user.followers_count)))
+        favorites = Text(_('favorites:\n{0}'.format(user.favorites_count)))
         stats = Columns([following, followers, favorites])
 
         widgets.extend([stats, whitespace])
@@ -1226,5 +1226,24 @@ class UserInfo(WidgetWrap):
 
         pile = Pile(widgets)
 
-        WidgetWrap.__init__(self, LineBox(title='@{}'.format(user.screen_name),
-                                          original_widget=pile))
+        super(UserInfo, self).__init__(LineBox(title='@{0}'.format(user.screen_name),
+                                       original_widget=pile))
+
+
+def sanitize(text):
+    if isinstance(text, unicode):
+        return html_unescape(text)
+    else:
+        return text
+
+def html_unescape(string):
+    """Unescape HTML entities from ``string``."""
+    def entity_replacer(m):
+        entity = m.group(1)
+        if entity in entitydefs:
+            return entitydefs[entity]
+        else:
+            return m.group(0)
+
+    return re.sub(r'&([^;]+);', entity_replacer, string)
+
